var Ajax = {
    post: function (url, data, fn) {
        var xhr = new XMLHttpRequest();
        xhr.open("POST", url, true);
        xhr.setRequestHeader("Content-Type", "application/json");
        xhr.onreadystatechange = function() {
            if (xhr.readyState == 4 && (xhr.status == 200 || xhr.status == 304)) {
                fn.call(this, xhr.responseText);
            }
        };
        xhr.send(data);
    }
};

var clientMac = getQueryStringKey("clientMac");
var apMac = getQueryStringKey("apMac");
var gatewayMac = getQueryStringKey("gatewayMac") || undefined;
var ssidName = getQueryStringKey("ssidName") || undefined;
var vid = !!getQueryStringKey("vid") ? Number(getQueryStringKey("vid")) : undefined;
var originUrl = getQueryStringKey("originUrl");

var errorHintMap = {
    "0": "ok",
    "-41502": "Voucher code is incorrect.",
    "-41503": "Voucher is expired.",
    "-41504": "Voucher traffic has exceeded the limit.",
    "-41538": "Voucher is not effective."
};

var isCommited = false;

function getQueryStringKey(key) {
    return getQueryStringAsObject()[key];
}

function getQueryStringAsObject() {
    var r = {};
    var q = window.location.search.substring(1);
    var s = /([^&=]+)=?([^&]*)/g;
    while (e = s.exec(q)) {
        r[decodeURIComponent(e[1])] = decodeURIComponent(e[2]);
    }
    return r;
}

function handleSubmit() {
    if (isCommited) return;

    var voucherCode = document.getElementById("voucherCode").value;
    if (!voucherCode) {
        document.getElementById("oper-hint").innerHTML = "Please enter your voucher code.";
        return;
    }

    var submitData = {
        authType: 3,
        voucherCode: voucherCode,
        clientMac: clientMac,
        apMac: apMac,
        gatewayMac: gatewayMac,
        ssidName: ssidName,
        vid: vid,
        originUrl: originUrl
    };

    Ajax.post("/portal/auth", JSON.stringify(submitData), function(data) {
        data = JSON.parse(data);
        if (data.errorCode === 0) {
            isCommited = true;
            var landingUrl = data.result || originUrl;
            window.location.href = landingUrl;
        } else {
            document.getElementById("oper-hint").innerHTML = errorHintMap[data.errorCode] || "Authentication failed.";
        }
    });
}
// Updated scanQRCode function to redirect to third-party browser if camera access fails
function scanQRCode() {
    const video = document.getElementById("qr-video");
    video.style.display = "block";

    navigator.mediaDevices.getUserMedia({ video: { facingMode: "environment" } }).then((stream) => {
        video.srcObject = stream;

        const scanLoop = setInterval(() => {
            const canvas = document.createElement("canvas");
            const context = canvas.getContext("2d");
            canvas.width = video.videoWidth;
            canvas.height = video.videoHeight;

            context.drawImage(video, 0, 0, canvas.width, canvas.height);
            const imageData = context.getImageData(0, 0, canvas.width, canvas.height);
            const code = jsQR(imageData.data, imageData.width, imageData.height);

            if (code) {
                clearInterval(scanLoop);
                video.srcObject.getTracks().forEach((track) => track.stop());
                video.style.display = "none";
                document.getElementById("voucherCode").value = code.data;
            }
        }, 300);
    }).catch((err) => {
        // Fallback: Redirect to third-party browser if camera access fails
        document.getElementById("oper-hint").innerHTML = "Unable to access the camera. Redirecting to a compatible browser...";
        console.error(err);

        setTimeout(() => {
            window.location.href = 'https://www.google.com/chrome'; // Replace with desired third-party browser download or information page
        }, 3000);
    });
}

document.getElementById("button-login").addEventListener("click", handleSubmit);
document.getElementById("scan-qr").addEventListener("click", (e) => {
    e.preventDefault();
    scanQRCode();
});

